{ config, pkgs, ... }: let
  image = name: "ghcr.io/genudine/saerro/${name}:latest";
  port = n: builtins.toString (8100 + n);
  containerGenerics = {
    environmentFiles = [
      config.sops.secrets.saerro.path
    ];
    extraOptions = [
      "--pod=saerro"
      #"--pull=always"
    ];
    autoStart = true;
  };
  ctrToSysd = names: map (x: "podman-saerro_${x}.service") names;
in {

  sops.secrets.saerro = {
    sopsFile = ../../../secrets/blueberry/saerro.yaml;
  };

  virtualisation.oci-containers.containers = {
    saerro_api = {
      image = image "api";
      environment = {
        PORT = port 1;
        WEBSOCKET_HEALTHCHECK = "http://127.0.0.1:${port 2}/healthz";
      };
      dependsOn = [ "saerro_maint" "saerro_postgres" ];
    } // containerGenerics;

    saerro_ws = {
      image = image "websocket";
      environment = {
        PORT = port 2;
        WORLDS = "all";
      };
      dependsOn = [ "saerro_maint" "saerro_postgres" ];
    } // containerGenerics;

    saerro_maint = {
      image = image "tasks";
      cmd = [ "auto-maintenance" ];
      dependsOn = [ "saerro_postgres" ];
    } // containerGenerics;

    saerro_postgres = {
      image = "docker.io/timescale/timescaledb:latest-pg15";
      volumes = [
        "saerrodb:/var/lib/postgresql/data"
      ];
    } // containerGenerics;
  };

  systemd.services.create-saerro-pod = {
    serviceConfig.Type = "oneshot";
    wantedBy = ctrToSysd [ "api" "ws" "maint" "postgres" ];
    script = ''
      ${pkgs.podman}/bin/podman pod exists saerro || \
      ${pkgs.podman}/bin/podman pod create -n saerro -p '0.0.0.0:${port 1}:${port 1}'
    '';
  };

  # TODO: Automatic restart and pull

  services.nginx.virtualHosts = {
    "saerro.ps2.live" = {
      serverAliases = [ "saerro-new.ps2.live" ];
      locations."/".proxyPass = "http://127.0.0.1:${port 1}";
    };
  };
}
